@@ -56,7 +56,9 @@ class Patch(AnyEntity):
     def patch_files(self):
         return set(vc.file.path for vc in self.patch_revision)
 
-    active_states = ('pending-review', 'in-progress')
+    non_final_states = set( ('deleted', 'reviewed', 'pending-review', 'in-progress') )
+    active_states = set( ('reviewed', 'pending-review', 'in-progress') )
+
     def is_active(self):
         return self.cw_adapt_to('IWorkflowable').state in self.active_states
 
@@ -97,9 +99,11 @@ class PatchReviewBehaviour(EntityAdapter):
     __select__ = is_instance('Patch')
 
     def reviewers_rset(self):
+        # ensure patch author can't review its own patch
         return self._cw.execute(
             'Any U WHERE EXISTS(U in_group G, G name "reviewers") '
-            'OR EXISTS(P patch_repository R, R repository_reviewer U, P eid %(p)s)',
+            'OR EXISTS(P patch_repository R, R repository_reviewer U), '
+            'NOT P created_by U, P eid %(p)s',
             {'p': self.entity.eid})
 
     def set_reviewers(self, transition):
