@@ -21,8 +21,7 @@ import re
 
 from cubicweb.server import hook
 from cubicweb.selectors import is_instance, on_fire_transition
-from cubicweb.sobjects import notification
-from cubicweb.hooks import notification as notificationhooks
+from cubicweb.hooks import notification
 
 IGNORE_FILES = set( ('README', 'series', 'status', '.hgignore', '.hgtags') )
 
@@ -61,8 +60,8 @@ class LinkOrCreatePatchOp(hook.DataOperationMixIn, hook.Operation):
             # patch file is being removed: mark it on the patch entity if still
             # active
             if (entity.__regid__ == 'DeletedVersionContent'
-                and patch.is_active()
-                and entity.rev.branch == patch.branch):
+                and entity.rev.branch == patch.branch
+                and patch.is_active()):
                 MarkPatchAsDeletedOp.get_instance(self.session).add_data(patch)
 
 
@@ -82,6 +81,28 @@ class LinkOrCreatePatchHook(hook.Hook):
         LinkOrCreatePatchOp.get_instance(self._cw).add_data(entity)
 
 
+class InitPatchCreatorHook(hook.Hook):
+    __regid__ = 'vcreview.patch.created'
+    __select__ = hook.Hook.__select__ & is_instance('Patch')
+    events = ('before_add_entity',)
+    category = 'metadata'
+
+    def __call__(self):
+        email = self.entity.originator.rsplit('<')[-1].rsplit('>')[0]
+        rset = self._cw.execute('Any X WHERE X is CWUser, X use_email E, '
+                                'E address %(email)s', {'email': email})
+        relations = []
+        for ueid, in rset:
+            relations.append( (self.entity.eid, ueid) )
+            # ensure user is in the nosy-list
+            self._cw.execute('SET P nosy_list U WHERE P eid %(p)s, U eid %(u)s,'
+                             'NOT P nosy_list U',
+                             {'p': self.entity.eid, 'u': ueid})
+        if relations:
+            self._cw.add_relations([('created_by', relations),
+                                    ('owned_by', relations)])
+
+
 # use late operation to be executed after workflow operation
 class SearchPatchStateInstructionOp(hook.DataOperationMixIn,
                                     hook.LateOperation):
@@ -108,9 +129,9 @@ class SearchPatchStateInstructionOp(hook.DataOperationMixIn,
                 if vc.__regid__ == 'VersionContent':
                     if pstate == 'in-progress':
                         readycandidates[vc.file.path.lower()] = vc.patch
-                    elif pstate == 'pending-review':
+                    elif pstate in ('pending-review', 'reviewed'):
                         pendingcandidates[vc.file.path.lower()] = vc.patch
-                elif (pstate in ('in-progress', 'pending-review', 'deleted') and
+                elif (pstate in vc.patch.non_final_states and
                       vc.__regid__ == 'DeletedVersionContent'):
                     rejectcandidates[vc.file.path.lower()] = vc.patch
             interestingwords = set( ('ready', 'applied', 'reject', 'fold') )
@@ -129,7 +150,7 @@ class SearchPatchStateInstructionOp(hook.DataOperationMixIn,
                              rev.author, rev.changeset or rev.revision))
                 elif words[0] == 'refuse' and words[1] in pendingcandidates:
                     patch = pendingcandidates.pop(words[1])
-                    fire(patch, 'refuse', u'refused by %s in %s' % (
+                    fire(patch, 'ask rework', u'refused by %s in %s' % (
                         rev.author, rev.changeset or rev.revision))
                 elif words[0] == 'reject' and words[1] in rejectcandidates:
                     patch = rejectcandidates.pop(words[1])
@@ -215,33 +236,11 @@ class ReviewerSetHook(hook.Hook):
         view = self._cw.vreg['views'].select(
             'vcreview.notifications.reviewer-set', self._cw,
             rset=rset, user=self._cw.eid_rset(self.eidto).get_entity(0, 0))
-        notificationhooks.RenderAndSendNotificationView(self._cw, view=view)
+        notification.RenderAndSendNotificationView(self._cw, view=view)
         # ensure user is in the nosy-list
         self._cw.execute('SET P nosy_list U WHERE P eid %(p)s, U eid %(u)s, NOT P nosy_list U',
                          {'p': self.eidfrom, 'u': self.eidto})
 
-class ReviewerSetNotificationView(notification.NotificationView):
-    __regid__ = 'vcreview.notifications.reviewer-set'
-    __select__ = is_instance('Patch')
-    content = _('''
-You have been assigned for review of patch %(title)s
-
-url: %(url)s
-''')
-    def recipients(self):
-        reviewer = self.cw_extra_kwargs['user']
-        email = reviewer.cw_adapt_to('IEmailable').get_email()
-        if email:
-            return [(email, reviewer.property_value('ui.language'))]
-        return []
-
-    def subject(self):
-        patch = self.cw_rset.get_entity(0, 0)
-        return self._cw._('[%(repo)s] patch %(patch)s has been assigned to you') % {
-            'app': self._cw.vreg.config.appid,
-            'repo': patch.repository.dc_title(),
-            'patch': patch.dc_title()}
-
 from cubes.nosylist import hooks as nosylist
 nosylist.S_RELS |= set(('has_activity', 'patch_revision'))
 # XXX should add 'comments' relation in set below
