@@ -31,11 +31,11 @@ deleted    = pwf.add_state(_('deleted'))
 
 pwf.add_transition(_('ask review'), inprogress, pending,
                    ('managers', 'users',)) # XXX patch owner only?
-pwf.add_transition(_('accept'), (inprogress, pending, deleted), reviewed,
+pwf.add_transition(_('accept'), (inprogress, pending), reviewed,
                    ('managers', 'committers', 'reviewers',),
                    ('X patch_repository R, R repository_committer U',
                     'X patch_repository R, R repository_reviewer U')) # XXX patch_reviewer/repo manager only?
-pwf.add_transition(_('refuse'), (pending, reviewed), inprogress,
+pwf.add_transition(_('ask rework'), (pending, reviewed), inprogress,
                    ('managers', 'committers', 'reviewers',),
                    ('X patch_repository R, R repository_committer U',
                     'X patch_repository R, R repository_reviewer U')) # XXX patch_reviewer/repo manager only? ignore patch_reviewer if in reviewed state?
