@@ -20,7 +20,7 @@ _ = unicode
 
 from yams.buildobjs import EntityType, RelationDefinition, String
 
-from cubicweb.schema import WorkflowableEntityType, RQLConstraint
+from cubicweb.schema import WorkflowableEntityType, RQLConstraint, RRQLExpression
 
 # XXX nosylist. notifications: send all review (eg task + commment) at wf transition time
 
@@ -86,6 +86,42 @@ class applied_at(RelationDefinition):
     constraints = [RQLConstraint('S patch_repository PR, O from_repository R, '
                                  'R has_patch_repository PR')]
 
+class repository_committer(RelationDefinition):
+    __permissions__ = {
+        'read': ('managers', 'users', 'guests'),
+        'add': ('managers',),
+        'delete': ('managers',),
+        }
+    subject = 'Repository'
+    object = 'CWUser'
+
+class repository_reviewer(RelationDefinition):
+    __permissions__ = {
+        'read': ('managers', 'users', 'guests'),
+        'add': ('managers', 'committers',
+                RRQLExpression('S patch_repository R, R repository_committer U')),
+        'delete': ('managers', 'committers',
+                   RRQLExpression('S patch_repository R, R repository_committer U')),
+        }
+    subject = 'Repository'
+    object = 'CWUser'
+
+class patch_reviewer(RelationDefinition):
+    __permissions__ = {
+        'read': ('managers', 'users', 'guests'),
+        'add': ('managers', 'committers',
+                RRQLExpression('S patch_repository R, R repository_committer U')),
+        'delete': ('managers', 'committers',
+                   RRQLExpression('S patch_repository R, R repository_committer U')),
+        }
+    subject = 'Patch'
+    object = 'CWUser'
+    constraints = [RQLConstraint('EXISTS(U in_group G, G name "reviewers") '
+                                 'OR EXISTS(X patch_repository R, R repository_reviewer U)')]
+
+class patch_depends_on(RelationDefinition):
+    subject = 'Patch'
+    object = 'Patch'
 
 # ability to reference diff chunks #############################################
 
