@@ -11,7 +11,7 @@ class PatchStatusChangeView(StatusChangeMixIn, NotificationView):
 
     def subject(self):
         entity = self.cw_rset.get_entity(0, 0)
-        return self._cw._(u'[%(repo)s] patch %(patch)s is now in state "%(state)s"') % {
+        return self._cw._(u'[patch %(state)s] %(patch)s (%(repo)s)') % {
             'repo': entity.repository.dc_title(),
             'patch': entity.dc_title(),
             'state': self._cw.__(self._kwargs['current_state'])}
@@ -52,12 +52,35 @@ class TaskAddedView(task.TaskAddedView):
             patch = patch.parent.patch
             if not patch:
                 return super(TaskAddedView, self).subject()
-        return self._cw._(u'[%(repo)s] new task for %(patch)s: %(task)s') % {
+        return self._cw._(u'[patch task] %(patch)s: %(task)s (%(repo)s)') % {
             'repo': patch.repository.dc_title(),
             'patch': patch.dc_title(),
             'task': entity.dc_title()}
 
 
+class ReviewerSetNotificationView(NotificationView):
+    __regid__ = 'vcreview.notifications.reviewer-set'
+    __select__ = is_instance('Patch')
+    content = _('''
+You have been assigned for review of patch %(title)s
+
+url: %(url)s
+''')
+    def recipients(self):
+        reviewer = self.cw_extra_kwargs['user']
+        email = reviewer.cw_adapt_to('IEmailable').get_email()
+        if email:
+            return [(email, reviewer.property_value('ui.language'))]
+        return []
+
+    def subject(self):
+        patch = self.cw_rset.get_entity(0, 0)
+        return self._cw._('[patch assigned] %(patch)s (%(repo)s)') % {
+            'app': self._cw.vreg.config.appid,
+            'repo': patch.repository.dc_title(),
+            'patch': patch.dc_title()}
+
+
 def registration_callback(vreg):
     vreg.register_all(globals().values(), __name__, (TaskAddedView,))
     vreg.register_and_replace(TaskAddedView, task.TaskAddedView)
