@@ -44,16 +44,17 @@ class AutomaticWebTest(testlib.AutomaticWebTest):
             rmtree(cls.repo_path)
         except:
             pass
+
     # XXX presetup
     def custom_populate(self, how_many, cursor):
         req = self.request()
-        req.create_entity('Repository', type=u'mercurial',
-                          path=unicode(self.repo_path), encoding=u'utf8')
+        req.create_entity('Repository', type=u'mercurial', encoding=u'utf8',
+                          path=self.repo_path)
         assert req.execute('SET X has_patch_repository X')
         self.commit()
         init_vcsrepo(self.repo)
 
-AutomaticWebTest.repo_path = osp.join(AutomaticWebTest.datadir, 'patchrepo')
+AutomaticWebTest.repo_path = osp.join(AutomaticWebTest.datadir, u'patchrepo')
 
 if __name__ == '__main__':
     from logilab.common.testlib import unittest_main
