@@ -51,5 +51,10 @@ class DiffParserTC(TestCase):
         self.assertEqual(self.ipid, '1')
         self.assertTrue(htmldata.startswith('<div class="text/x-diff">'))
 
+    def test_insert_point_3(self):
+        htmldata = self.transform('nonregr2.diff')
+        self.assertEqual(self.ipid, '2')
+        self.assertTrue(htmldata.startswith('<div class="text/x-diff">'))
+
 if __name__ == '__main__':
     unittest_main()
