@@ -14,24 +14,24 @@
 # You should have received a copy of the GNU Lesser General Public License along
 # with this program. If not, see <http://www.gnu.org/licenses/>.
 
+from os import path as osp
 from shutil import rmtree
 
 from logilab.common.shellutils import unzip
 from logilab.common.testlib import mock_object
 
-from cubicweb.devtools.testlib import MAILBOX
+from cubicweb.devtools.testlib import MAILBOX, CubicWebTC
 
-from cubes.vcsfile.testutils import VCSRepositoryTC
+from cubes.vcsfile.testutils import init_vcsrepo
 from cubes.vcreview import hooks
 
 def revnums(patch):
     return sorted(vc.revision for vc in patch.patch_revision)
 
 
-class PatchCreationHooksTC(VCSRepositoryTC):
+class PatchCreationHooksTC(CubicWebTC):
     _repo_path = u'patchrepo'
     repo_title = u'patch repository'
-    commitevery = 1
 
     @classmethod
     def setUpClass(cls):
@@ -44,16 +44,26 @@ class PatchCreationHooksTC(VCSRepositoryTC):
         except:
             pass
 
-    def setup_database(self):
-        super(PatchCreationHooksTC, self).setup_database()
-        assert self.execute('INSERT EmailAddress E: E address "admin@cwo", U primary_email E '
-                            'WHERE U login "admin"')
+    def setUp(self):
+        super(PatchCreationHooksTC, self).setUp()
+        # XXX do this in setUp instead of setup_database else mailbox is reseted
+        # while this test check notifications
+        req = self.request()
+        assert req.execute('INSERT EmailAddress E: E address "admin@cwo", U primary_email E '
+                    'WHERE U login "admin"')
+        self.vcsrepo = self._create_repo(req)
+        self.commit()
+        init_vcsrepo(self.repo)
+        self.commit()
 
-    def _create_repo(self):
-        vcsrepo = super(PatchCreationHooksTC, self)._create_repo()
+    def _create_repo(self, req):
+        vcsrepo = req.create_entity(
+            'Repository', type=u'mercurial', encoding=u'utf-8',
+            import_revision_content=True,
+            path=self.repo_path, title=self.repo_title)
         # circular relations, only to make it think it is a patch repository
         vcsrepo.set_relations(has_patch_repository=vcsrepo,
-                              repository_reviewer=self.user())
+                              repository_reviewer=req.user)
         return vcsrepo
 
     def test_imported_patches(self):
@@ -100,8 +110,7 @@ class PatchCreationHooksTC(VCSRepositoryTC):
 
         self.assertTrue(patch3_2.nosy_list)
         self.assertEqual(len(MAILBOX), 3)
-        self.assertEqual(MAILBOX[0].subject, '[%s] patch %s is now in state "pending-review"'
-                         % (patch3_2.repository.dc_title(), patch3_2.dc_title()))
+        self.assertEqual(MAILBOX[0].subject, '[patch pending-review] patch3.diff (patch repository)')
         self.assertEqual(MAILBOX[0].recipients, ['admin@cwo'])
         self.assertMultiLineEqual(MAILBOX[0].content, u'''
 cubicweb changed status from <in-progress> to <pending-review> for entity
@@ -111,16 +120,14 @@ review asked by Sylvain Th\xe9nault <sylvain.thenault@logilab.fr> in 9cf50f15d9a
 
 url: http://testing.fr/cubicweb/patch/%s\n''' % patch3_2.eid)
 
-        self.assertEqual(MAILBOX[1].subject, '[%s] patch %s has been assigned to you'
-                         % (patch3_2.repository.dc_title(), patch3_2.dc_title()))
+        self.assertEqual(MAILBOX[1].subject, '[patch assigned] patch3.diff (patch repository)')
         self.assertEqual(MAILBOX[1].recipients, ['admin@cwo'])
         self.assertMultiLineEqual(MAILBOX[1].content, u'''
 You have been assigned for review of patch patch3.diff
 
 url: http://testing.fr/cubicweb/patch/%s\n''' % patch3_2.eid)
 
-        self.assertEqual(MAILBOX[2].subject, '[%s] patch %s is now in state "rejected"'
-                         % (patch3_2.repository.dc_title(), patch3_2.dc_title()))
+        self.assertEqual(MAILBOX[2].subject, '[patch rejected] patch3.diff (patch repository)')
         self.assertEqual(MAILBOX[2].recipients, ['admin@cwo'])
         self.assertMultiLineEqual(MAILBOX[2].content, u'''
 cubicweb changed status from <pending-review> to <rejected> for entity
@@ -136,8 +143,7 @@ url: http://testing.fr/cubicweb/patch/%s\n''' % patch3_2.eid)
         done = req.create_entity('Task', title=u'done', reverse_has_activity=patch3_2)
         self.commit()
         self.assertEqual(len(MAILBOX), 2)
-        self.assertEqual(MAILBOX[1].subject, '[%s] new task for %s: done'
-                         % (patch3_2.repository.dc_title(), patch3_2.dc_title()))
+        self.assertEqual(MAILBOX[1].subject, '[patch task] patch3.diff: done (patch repository)')
         self.assertEqual(MAILBOX[1].recipients, ['admin@cwo'])
         self.assertMultiLineEqual(MAILBOX[1].content, u'''
 done
@@ -174,8 +180,7 @@ url: http://testing.fr/cubicweb/task/%s\n''' % done.eid)
         #self.assertEqual(patch3_2.applied_at[0].eid, patch3_2.revisions[-1].rev.eid) XXX
 
         self.assertEqual(len(MAILBOX), 1, MAILBOX)
-        self.assertEqual(MAILBOX[0].subject, '[%s] patch %s is now in state "applied"'
-                         % (patch3_2.repository.dc_title(), patch3_2.dc_title()))
+        self.assertEqual(MAILBOX[0].subject, '[patch applied] patch3.diff (patch repository)')
         self.assertEqual(MAILBOX[0].recipients, ['admin@cwo'])
         self.assertMultiLineEqual(MAILBOX[0].content, u'''
 admin changed status from <pending-review> to <applied> for entity
@@ -190,6 +195,7 @@ remaining tasks:
 url: http://testing.fr/cubicweb/patch/%s\n''' % patch3_2.eid)
 
 
+PatchCreationHooksTC.repo_path = osp.join(PatchCreationHooksTC.datadir, u'patchrepo')
 
 if __name__ == '__main__':
     from logilab.common.testlib import unittest_main
