@@ -112,7 +112,7 @@ class ActivityComponent(component.EntityCtxComponent):
     def display_existing_tasks(self, w):
         rset = self._cw.execute(self.existing_tasks_rql, {'x': self.entity.eid})
         if rset:
-            w(u'<div class="componentTitle">%s</div>' % self._cw._('Activities'))
+            w(u'<h4>%s</h4>' % self._cw._('Activities'))
             self._cw.view('editable-table', rset, w=w,
                           headers=[self._cw.__('Task_plural'),
                                    self._cw._('detail'),
