@@ -28,6 +28,13 @@ class PatchRepositoryFacet(facet.RelationFacet):
     label_vid = 'text'
 
 
+class PatchReviewerFacet(facet.RelationFacet):
+    __regid__ = 'vcreview.patch_reviewer'
+    rtype = 'patch_reviewer'
+    role = 'subject'
+    target_attr = 'login'
+
+
 class PatchOriginatorFacet(facet.AttributeFacet):
     __regid__ = 'vcreview.patch.originator'
     __select__ = facet.AttributeFacet.__select__ & is_instance('Patch')
