@@ -28,6 +28,7 @@ from cubicweb.web import uicfg
 from cubicweb.web.views import primary, ibreadcrumbs
 
 from cubes.vcsfile.views import primary as vcsfile
+from cubes.vcreview.views import patch_states_rql
 
 _pvs = uicfg.primaryview_section
 _pvdc = uicfg.primaryview_display_ctrl
@@ -146,7 +147,7 @@ class RepositoryPatchesTable(EntityView):
     __regid__ = 'vcreview.repository.patches'
     __select__ = is_instance('Repository') & score_entity(lambda x: x.patchrepo_of)
 
-    rql = ('Any P,PO,PB,PS,COUNT(TR) GROUPBY P,PO,PB,PS WHERE '
+    rql = ('Any P,PO,P,PB,PS,COUNT(TR) GROUPBY P,PO,PB,PS WHERE '
            'P originator PO, P branch PB, P in_state PS, TR? wf_info_for P, '
            'P patch_repository R, R eid %(x)s')
 
@@ -157,9 +158,9 @@ class RepositoryPatchesTable(EntityView):
         self.w('<p>%s. <a href="%s">%s</a></p>' % (
             self._cw._('Table below only show active patches'),
             xml_escape(linkurl), self._cw._('Show all patches')))
-        rql = self.rql + ', PS name IN ("in-progress", "pending-review", "deleted")'
+        rql = self.rql + ', PS name %s' % patch_states_rql(self._cw)
         rset = self._cw.execute(rql, {'x': entity.eid})
-        self.wview('table', rset, 'noresult', paginate=True, displayfilter=True)
+        self.wview('vcreview.patches.table', rset, 'noresult', displayfilter=True)
 
 
 # breadcrumbs ##################################################################
